"""
Seeds the database with test data.
You can call this by python manage.py seed_db
"""

import random

from django.core.files.uploadedfile import SimpleUploadedFile
from django.core.management import call_command
from django.core.management.base import BaseCommand
from quiz.models import (
    Sport,
    Criterion,
    Question,
    CallToMove,
    KnowledgeSnack,
)


class Command(BaseCommand):
    """
    Seeds the database with test data.
    You can call this by python manage.py seed_db
    """

    help = "Seeds the database with test data"

    def add_arguments(self, parser):
        """
        Add arguments to command that can be added to the command in command line
        In this case there's only one arg that you can call by
        python manage.py seed_db --yes
        """
        parser.add_argument(
            "-y",
            "--yes",
            action="store_true",
            help="Don't ask to confirm database flushing",
        )

        parser.add_argument(
            "--seed",
            type=int,
            default=42,
            help="Optional seed for random generator. Defaults to 42",
        )
        parser.add_argument(
            "--no-superuser",
            action="store_true",
            help="No super user shall be created",
        )

    def handle(self, *args, **options):
        """Create some objects for all models"""

        # delete all present database entries (necessary because of unique constraints)
        call_command("flush", "--no-input" if options["yes"] else [])

        # Create admin user for using django admin interface during development
        if not options["no_superuser"]:
            self.stdout.write("\nSpecify admin password for development:")
            call_command("createsuperuser", "--username=admin", "--email=''")

        # Seed random generator to make this script deterministic
        random.seed(options["seed"])

        # Create sports
        sports_names = [
            "After Work Fitness",
            "Ballett",
            "Basketball",
            "Beachvolleyball",
            "Bouldern",
        ]
        for name in sports_names:
            Sport(name=name).save()

        # Create criteria
        criteria_names = [
            "Einzelsport",
            "Mannschaftssport",
            "Ausdauer",
            "Kraft",
            "Kampfsport",
        ]
        for name in criteria_names:
            Criterion(name=name).save()

        # Create ratings for all sports and criterions
        for sport in Sport.objects.all():
            for criterion in Criterion.objects.all():
                sport.rate(criterion, random.randint(1, 10))

        # Create questions
        questions = [
            "Ich würde am liebsten gemeinsam mit anderen trainieren.",
            "Teamgeist und Wir-Gefühl sind für mich beim Sport eine große Motivation.",
            "Ich betreibe lieber alleine Sport.",
            "Ich bin bereit, mir ggf. Material für die Sportart zu kaufen.",
            "Ich bevorzuge das Sportangebot draußen in der Natur vor dem Indoor-Angebot.",
        ]

        for number, criterion in enumerate(Criterion.objects.all()):
            Question(text=questions[number], criterion=criterion).save()

        # Create Calls to Move
        calls_to_move = [
            "Kreise deine Schultern vor der nächsten Frage 3x nach hinten",
            "Stehe auf, beuge dich mit gestrecktem Rücken nach vorne und greife deinen Stuhl.",
            "Mache vor der nächsten Frage 3 Jumping Jacks",
        ]
        image = SimpleUploadedFile(
            name="test_image.png",
            content=open("quiz/fixtures/images/test_image.png", "rb").read(),
            content_type="image/png",
        )

        for text in calls_to_move:
            CallToMove(text=text, image=image).save()

        # Create Knowledge Snacks
        knowledge_snacks = [
            "Dass Treppensteigen fast 5x so viele Kalorien verbrennt, wie das Nutzen des Aufzuges?",
            "Dass das Spielemobil zur Mittagszeit immer auf dem Campus unterwegs ist?",
            "Dass regelmäßige Bewegung Herz-Kreislauf-Erkrankungen vorbeugt?",
        ]
        image = SimpleUploadedFile(
            name="logo.png",
            content=open("quiz/fixtures/images/logo.png", "rb").read(),
            content_type="image/png",
        )
        for text in knowledge_snacks:
            KnowledgeSnack(text=text, image=image).save()
